@@ -26,6 +26,7 @@ def load_channel(subdir_data, result_container):
 def get_index(channel_urls=(), prepend=True, platform=None,
               use_local=False, use_cache=False, unknown=None, prefix=None,
               repodata_fn="repodata.json"):
+
     real_urls = calculate_channel_urls(channel_urls, prepend, platform, use_local)
     check_whitelist(real_urls)
 
@@ -33,13 +34,14 @@ def get_index(channel_urls=(), prepend=True, platform=None,
 
     sddata = []
     index = []
+
     for idx, url in enumerate(real_urls):
         channel = Channel(url)
 
         full_url = channel.url(with_credentials=True) + '/' + repodata_fn
         full_path_cache = os.path.join(
-            create_cache_dir(),
-            cache_fn_url(full_url, repodata_fn))
+            api.create_cache_dir(),
+            api.cache_fn_url(full_url))
 
         sd = api.SubdirData(channel.name + '/' + channel.subdir,
                             full_url,
@@ -56,21 +58,25 @@ def get_index(channel_urls=(), prepend=True, platform=None,
 
     return index
 
-def init_api_context():
+def init_api_context(use_mamba_experimental=False):
     api_ctx = api.Context()
+
     api_ctx.json = context.json
     api_ctx.dry_run = context.dry_run
     if context.json:
         context.always_yes = True
         context.quiet = True
-        context.json = False
-        context.dry_run = False
+        if use_mamba_experimental:
+            context.json = False
+            # context.dry_run = False
     api_ctx.set_verbosity(context.verbosity)
     api_ctx.quiet = context.quiet
     api_ctx.offline = context.offline
     api_ctx.local_repodata_ttl = context.local_repodata_ttl
     api_ctx.use_index_cache = context.use_index_cache
     api_ctx.always_yes = context.always_yes
+    api_ctx.channels = context.channels
+
     if context.ssl_verify == False:
         api_ctx.ssl_verify = "<false>"
     elif context.ssl_verify is not True:
@@ -81,9 +87,11 @@ def init_api_context():
     api_ctx.connect_timeout_secs = int(round(context.remote_connect_timeout_secs))
     api_ctx.max_retries = context.remote_max_retries
     api_ctx.retry_backoff = context.remote_backoff_factor
+    api_ctx.add_pip_as_python_dependency = context.add_pip_as_python_dependency
 
 def to_package_record_from_subjson(channel, pkg, jsn_string):
     channel = channel
+    # print(channel, pkg, jsn_string)
     channel_url = channel.url(with_credentials=True)
     info = json.loads(jsn_string)
     info['fn'] = pkg
